@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::Yancy;
-our $VERSION = '0.023';
+our $VERSION = '1.000';
 # ABSTRACT: Embed a simple admin CMS into your Mojolicious application
 
 #pod =head1 SYNOPSIS
@@ -482,8 +482,10 @@ sub _build_openapi_spec {
     for my $name ( keys %{ $config->{collections} } ) {
         # Set some defaults so users don't have to type as much
         my $collection = $config->{collections}{ $name };
+        next if $collection->{ 'x-ignore' };
         $collection->{ type } //= 'object';
         my $id_field = $collection->{ 'x-id-field' } // 'id';
+        my %props = %{ $collection->{ properties } };
 
         $definitions{ $name . 'Item' } = $collection;
         $definitions{ $name . 'Array' } = {
@@ -518,6 +520,13 @@ sub _build_openapi_spec {
                         pattern => '^(?:asc|desc):[^:,]+$',
                         description => 'How to sort the list. A string containing one of "asc" (to sort in ascending order) or "desc" (to sort in descending order), followed by a ":", followed by the field name to sort by.',
                     },
+                    map {; {
+                        name => $_,
+                        in => 'query',
+                        type => ref $props{ $_ }{type} eq 'ARRAY'
+                            ? $props{ $_ }{type}[0] : $props{ $_ }{type},
+                        description => "Filter the list by the $_ field. By default, looks for rows containing the value anywhere in the column. Use '*' anywhere in the value to anchor the match.",
+                    } } keys %props,
                 ],
                 responses => {
                     200 => {
@@ -716,7 +725,7 @@ Mojolicious::Plugin::Yancy - Embed a simple admin CMS into your Mojolicious appl
 
 =head1 VERSION
 
-version 0.023
+version 1.000
 
 =head1 SYNOPSIS
 
