@@ -219,7 +219,9 @@ var app = new Vue({
             formError: {},
             info: {},
             sortColumn: null,
-            sortDirection: 1
+            sortDirection: 1,
+            newFilter: null,
+            filters: []
         }
     },
     methods: {
@@ -253,6 +255,25 @@ var app = new Vue({
             this.fetchPage();
         },
 
+        createFilter: function () {
+            this.newFilter = {};
+        },
+
+        addFilter: function () {
+            this.filters.push( this.newFilter );
+            this.cancelFilter();
+            this.fetchPage();
+        },
+
+        cancelFilter: function () {
+            this.newFilter = null;
+        },
+
+        removeFilter: function ( i ) {
+            this.filters.splice( i, 1 );
+            this.fetchPage();
+        },
+
         setCollection: function ( name ) {
             this.currentCollection = name;
             $( '#sidebar-collapse' ).collapse('hide');
@@ -380,6 +401,9 @@ var app = new Vue({
                 var dir = this.sortDirection > 0 ? 'asc' : 'desc';
                 query.$order_by = [ dir, this.sortColumn ].join( ':' );
             }
+            for ( var i = 0; i < this.filters.length; i++ ) {
+                query[ this.filters[i].field ] = this.filters[i].value;
+            }
 
             this.fetching = true;
             delete this.error.fetchPage;
