@@ -1,5 +1,5 @@
 package Yancy::Backend::Dbic;
-our $VERSION = '0.023';
+our $VERSION = '1.000';
 # ABSTRACT: A backend for DBIx::Class schemas
 
 #pod =head1 SYNOPSIS
@@ -201,8 +201,16 @@ sub read_schema {
                 push @{ $schema{ $table }{ required } }, $column;
             }
         }
-        my @keys = $source->primary_columns;
-        if ( $keys[0] ne 'id' ) {
+
+        my @keys = (
+            $source->primary_columns,
+            (
+                map { @$_ } grep { scalar( @$_ ) == 1 }
+                map { [ $source->unique_constraint_columns( $_ ) ] }
+                $source->unique_constraint_names
+            ),
+        );
+        if ( @keys && $keys[0] ne 'id' ) {
             $schema{ $table }{ 'x-id-field' } = $keys[0];
         }
     }
@@ -255,7 +263,7 @@ Yancy::Backend::Dbic - A backend for DBIx::Class schemas
 
 =head1 VERSION
 
-version 0.023
+version 1.000
 
 =head1 SYNOPSIS
 
