@@ -1,5 +1,5 @@
 package Yancy::Controller::Yancy::API;
-our $VERSION = '0.023';
+our $VERSION = '1.000';
 # ABSTRACT: An OpenAPI REST controller for the Yancy editor
 
 #pod =head1 DESCRIPTION
@@ -55,20 +55,31 @@ sub list_items {
     my ( $c ) = @_;
     return unless $c->openapi->valid_input;
     my $args = $c->validation->output;
+
     my %opt = (
-        limit => $args->{'$limit'},
-        offset => $args->{'$offset'},
+        limit => delete $args->{'$limit'},
+        offset => delete $args->{'$offset'},
     );
-    if ( $args->{'$order_by'} ) {
+    if ( my $order_by = delete $args->{'$order_by'} ) {
         $opt{order_by} = [
             map +{ "-$_->[0]" => $_->[1] },
             map +[ split /:/ ],
-            split /,/, $args->{'$order_by'}
+            split /,/, $order_by
         ];
     }
+
+    my %filter;
+    for my $key ( keys %$args ) {
+        my $value = $args->{ $key };
+        if ( ( $value =~ tr/*/%/ ) <= 0 ) {
+            $value = "\%$value\%";
+        }
+        $filter{ $key } = { -like => $value };
+    }
+
     return $c->render(
         status => 200,
-        openapi => $c->yancy->backend->list( $c->stash( 'collection' ), {}, \%opt ),
+        openapi => $c->yancy->backend->list( $c->stash( 'collection' ), \%filter, \%opt ),
     );
 }
 
@@ -159,7 +170,7 @@ Yancy::Controller::Yancy::API - An OpenAPI REST controller for the Yancy editor
 
 =head1 VERSION
 
-version 0.023
+version 1.000
 
 =head1 DESCRIPTION
 
