@@ -1,5 +1,5 @@
 package Yancy::Controller::Yancy::MultiTenant;
-our $VERSION = '0.023';
+our $VERSION = '1.000';
 # ABSTRACT: A controller to show a user only their content
 
 #pod =head1 SYNOPSIS
@@ -58,18 +58,44 @@ our $VERSION = '0.023';
 #pod     } );
 #pod
 #pod     # /:username - List blog posts
-#pod     app->routes->get( '' )->to(
+#pod     $user_route->get( '' )->to(
 #pod         'yancy-multi_tenant#list',
 #pod         collection => 'blog',
 #pod         template => 'blog_list',
 #pod     );
 #pod     # /:username/:id/:slug - Get a single blog post
-#pod     app->routes->get( '/:id/:slug' )->to(
+#pod     $user_route->get( '/:id/:slug' )->to(
 #pod         'yancy-multi_tenant#get',
 #pod         collection => 'blog',
 #pod         template => 'blog_view',
 #pod     );
 #pod
+#pod To build a website where content is only for the current logged-in user,
+#pod combine this controller with an auth plugin like
+#pod L<Yancy::Plugin::Auth::Basic>. Use an C<under> route to set the
+#pod C<user_id> from the current user.
+#pod
+#pod     app->yancy->plugin( 'Auth::Basic', {
+#pod         route => any( '' ), # All routes require login
+#pod         collection => 'user',
+#pod         username_field => 'username',
+#pod         password_digest => { type => 'SHA-1' },
+#pod     } );
+#pod
+#pod     my $user_route = app->yancy->auth->route->under( '/', sub {
+#pod         my ( $c ) = @_;
+#pod         my $user = $c->yancy->auth->current_user;
+#pod         $c->stash( user_id => $user->{id} );
+#pod         return 1;
+#pod     } );
+#pod
+#pod     # / - List todo items
+#pod     $user_route->get( '' )->to(
+#pod         'yancy-multi_tenant#list',
+#pod         collection => 'todo_item',
+#pod         template => 'todo_list',
+#pod     );
+#pod
 #pod =head1 SEE ALSO
 #pod
 #pod L<Yancy::Controller::Yancy>, L<Mojolicious::Controller>, L<Yancy>
@@ -294,7 +320,7 @@ Yancy::Controller::Yancy::MultiTenant - A controller to show a user only their c
 
 =head1 VERSION
 
-version 0.023
+version 1.000
 
 =head1 SYNOPSIS
 
@@ -490,18 +516,44 @@ in the path to the ID:
     } );
 
     # /:username - List blog posts
-    app->routes->get( '' )->to(
+    $user_route->get( '' )->to(
         'yancy-multi_tenant#list',
         collection => 'blog',
         template => 'blog_list',
     );
     # /:username/:id/:slug - Get a single blog post
-    app->routes->get( '/:id/:slug' )->to(
+    $user_route->get( '/:id/:slug' )->to(
         'yancy-multi_tenant#get',
         collection => 'blog',
         template => 'blog_view',
     );
 
+To build a website where content is only for the current logged-in user,
+combine this controller with an auth plugin like
+L<Yancy::Plugin::Auth::Basic>. Use an C<under> route to set the
+C<user_id> from the current user.
+
+    app->yancy->plugin( 'Auth::Basic', {
+        route => any( '' ), # All routes require login
+        collection => 'user',
+        username_field => 'username',
+        password_digest => { type => 'SHA-1' },
+    } );
+
+    my $user_route = app->yancy->auth->route->under( '/', sub {
+        my ( $c ) = @_;
+        my $user = $c->yancy->auth->current_user;
+        $c->stash( user_id => $user->{id} );
+        return 1;
+    } );
+
+    # / - List todo items
+    $user_route->get( '' )->to(
+        'yancy-multi_tenant#list',
+        collection => 'todo_item',
+        template => 'todo_list',
+    );
+
 =head1 SEE ALSO
 
 L<Yancy::Controller::Yancy>, L<Mojolicious::Controller>, L<Yancy>
